

// [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}]

export interface ContentValue {
  key: String
  value: String
  type: String
}

export interface kvForm {
  key: String
  value: String
}
export interface HttpHead {
  key: String
  value: String
}

declare class Device {

  /**
 * 获取web工作目录
 * @result H5应用工作目录
 */
  getWorkPath(): string

  /**
   * 获取H5应用环境api版本
   * @result api版本
   */
  getXApiVersion(): int
  /**
   * 打开扫码
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  startQrCode(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /**
     * 显示控制台按钮Console
     */
  showDebugConsoleButton(): void
  /**
    * 隐藏控制台按钮Console
  */
  dismissDebugConsoleButton(): void


  /**
    * 打开定位
    * @param {*} sCallback 
    * @param {*} eCallBack 
    */
  startLocationPromise(): Promise
  /**
    * 关闭定位
    * @param {*} sCallback 
    * @param {*} eCallBack 
    */
  stopLocationPromise(): Promise

  /**
     * 打开定位
     * @param {*} sCallback 
     * @param {*} eCallBack 
     */
  startLocation(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 关闭定位
  * @param {*} sCallback 
  * @param {*} eCallBack 
  */
  stopLocation(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 定位
  * @param {*} sCallback 
  * @param {*} eCallBack 
  */
  requestLocation(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 添加定位监听器
  * @param {*} sCallback 
  * @param {*} eCallBack 
  */
  addLocationListener(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 移除定位监听器
  * @param {*} sCallback 
  * @param {*} eCallBack 
  */
  removeLocationListener(sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void



  /**
   * 打开相机
   *  @param {string} paramJsonStr 传递到相机的参数
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  goTakePicture(paramJsonStr: string, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 打开相机
  *  @param {string} paramJsonStr 传递到相机的参数
  * @param {(sJson)=>{}} sCallback 
  * @param {(eJson)=>{}} eCallBack 
  */
  goTakePicturePromise(paramJsonStr: string): Promise

  /**
     * 通过url上传文件到远程服务器
     * @param {string} localPath 本地路径
     * @param {string} header 
     * @param {string} writeUrl 
     * @param {string} readUrl 
     * @param {(sJson)=>{}} sCallback 
     * @param {(eJson)=>{}} eCallBack 
     */
  putFile2CloudByUrl(localPath: string, header: string, writeUrl: string, readUrl: string, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /**
     * 通过url上传文件到远程服务器
     * @param {string} localPath 本地路径
     * @param {string} header 
     * @param {string} writeUrl 
     * @param {string} readUrl 
     */
  putFile2CloudByUrlPromise(localPath: string, header: string, writeUrl: string, readUrl: string): Promise



  /**
   * 上传文件到远程服务器
   * @param {string} localPath 本地路径
   * @param {string} header 
   * @param {string} writeUrl 
   * @param {string} readUrl 
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  putFile2Cloud(localPath: string, serverPath: string, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /**
     * 上传文件到远程服务器
     * @param {string} localPath 本地路径
     * @param {string} header 
     * @param {string} writeUrl 
     * @param {string} readUrl 
     */
  putFile2CloudPromise(localPath: string, serverPath: string): Promise

  /***
  * 初始化数据库
  * @param {String} dbPath 数据库路径
  * @param {String} dbName 数据库名字
    @param {(sJson)=>{}} sCallback 
  * @param {(eJson)=>{}} eCallBack 
  * 
  */
  initDB(dbPath: String, dbName: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
   * 打开数据库
   * @param {String} dbPath 数据库存储路径
   * @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {Boolean}  creata 数据库不存在是否创建
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   * 
   */
  openDB(dbKey: String, create: Boolean, sCallback: (sJson) => {}, eCallBack: (eJson) => {})
  /**
   *关闭数据库 
   * @param {*} dbKey dbKey initDB获取到的dbKey
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  closeDB(dbKey: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {})
  /**
   * 获取数据库版本号
   * @param {*} dbKey dbKey initDB获取到的dbKey
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  getDBVersion(dbKey: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
  * 获取数据库状态，是否正常打开
  * @param {*} dbKey dbKey initDB获取到的dbKey
  *  @param {(sJson)=>{}} sCallback 
  * @param {(eJson)=>{}} eCallBack 
  */
  getDBState(dbKey: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /** 
  *  执行sql语句，创建数据表等
   * 
   * <ul>
   *   <li>ALTER TABLE</li>
   *   <li>CREATE or DROP table / trigger / view / index / virtual table</li>
   *   <li>REINDEX</li>
   *   <li>RELEASE</li>
   *   <li>SAVEPOINT</li>
   *   <li>PRAGMA that returns no data</li>
   * </ul>
   *
   * the SQL statement to be executed. Multiple statements separated by semicolons are not supported.
   * 
  *  @param {String} dbKey dbKey initDB获取到的dbKey
  *  @param {String} sqlStr sql语句 
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
  */
  execSql(dbKey: String, sqlStr: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /***
   * 查询数据
     @param {String} dbKey dbKey initDB获取到的dbKey
  *  @param {Boolean} distinct true if you want each row to be unique, false otherwise
   * @param {String} table The table name to compile the query against.
   * @param {Array<String>} columns A list of which columns to return. Passing null will return all columns, which is discouraged to prevent reading data from storage that isn't going to be used.
   * @param {String} selection A filter declaring which rows to return, formatted as an SQL WHERE clause (excluding the WHERE itself). Passing null will return all rows for the given table.
   * @param {Array<String>} selectionArgs You may include ?s in selection, which will be replaced by the values from selectionArgs, in order that they appear in the selection. The values will be bound as Strings.
   * @param {String} groupBy A filter declaring how to group rows, formatted as an SQL GROUP BY clause (excluding the GROUP BY itself). Passing null will cause the rows to not be grouped.
   * @param {String} having A filter declare which row groups to include in the cursor, if row grouping is being used, formatted as an SQL HAVING clause (excluding the HAVING itself). 
   * Passing null will cause all row groups to be included, and is required when row grouping is not being used.
   * @param {String} orderBy How to order the rows, formatted as an SQL ORDER BY clause (excluding the ORDER BY itself). Passing null will use the default sort order, which may be unordered.
   * @param {String} limit Limits the number of rows returned by the query, formatted as LIMIT clause. Passing null denotes no LIMIT clause.
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   * 
   */
  queryDB(dbKey: String, distinct: Boolean, table: String, columns: Array<String>, selection: String,
    selectionArgs: Array<String>, groupBy: String, having: String,
    orderBy: String, limit: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /***
   * 查询sql数据
   * @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} querySql 查询sql语句
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  rawQuery(dbKey: String, querySql: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /***
   * 插入数据到数据库
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} table table  the table to insert the row into
   * @param {String} nullColumnHack nullColumnHack 
   *                     optional; may be null. SQL doesn't allow inserting a completely empty row without naming at least one column name.
   *                     If your provided values is empty, no column names are known and an empty row can't be inserted. 
   *                     If not set to null, the nullColumnHack parameter provides the name of nullable column name to explicitly insert a NULL into 
   *                     in the case where your values is empty.values – this map contains the initial column values for the row.
   *                     The keys should be the column names and the values the column values
   *  @param {String} contentValuesJsonArrayString contentValuesJsonArrayString  this map contains the initial column values for the row. 
   *                                         The keys should be the column names and the values the column values JSONArray  
   *                                           example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}] 
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   * 
   */

  insertDB(dbKey: String, table: String, nullColumnHack: String, contentValuesJsonArrayString: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /***
   * 删除数据库数据
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} table table the table to delete from
   * @param {String} whereClause the optional WHERE clause to apply when deleting. Passing null will delete all rows.
   *  @param {Array<String>} whereArgs You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
   *  @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */

  deleteDB(dbKey: String, table: String, whereClause: String, whereArgs: Array<String>, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /***
   * 更新数据库数据
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   *  @param {String} table table a map from column names to new column values. null is a valid value that will be translated to NULL.
   *  @param {String} contentValuesJsonArrayString contentValuesJsonArrayString  a map from column names to new column values. null is a valid value that will be translated to NULL. JSONArray   example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}] 
   *  @param {String} whereClause   the optional WHERE clause to apply when updating. Passing null will update all rows.
   *  @param {Array<String>} whereArgs   You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
   *  @param {(sJson)=>{}} sCallback 
   *  @param {(eJson)=>{}} eCallBack 
   */

  updateDB(dbKey: String, table: String, contentValuesJsonArrayString: String, whereClause: String, whereArgs: Array<String>, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void




  /**
   * http set head
   * @param {String} heads [{key:value}...]
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  httpSetHeads(heads: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /**
   *http post
   * @param {String} url    url
   * @param {String} requestBody  post请求体字符串
   * @param {String} bodyType   (json|form) 对应接口请求参数json字符串
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  send2ServerPost(url: String, requestBody: String, bodyType: "json" | "form", sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
   *http get
   * @param {String} url    url
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  send2ServerGet(url: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void



  /**
   * http下载文件到sd卡
   * @param {String} url 下载地址
   * @param {String} path 保存的路径
   * @param {String} file 保存的文件名
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  downloadFile(url: String, path: String, fileName: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void


  /**
   * 将文本内容固化到sd卡，可以保存json字符串或图片的base64字符串
   * @param {String} path       文件路径
   * @param {String} fileName   保存的文件名
   * @param {String} strString  字符串内容
   * @result true为成功，false为失败
   */
  writeText2Sdcard(path: String, fileName: String, strString: String): Boolean



  /**
    * 获取字符串md5值
    * @param {*} contentStr 
    * @returns 
    */
  getStrMd5(contentStr, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
   * 获取字符串Base64Encoder值
   * @param {*} contentStr 
   * @returns 
   */
  getStrBase64Encoder(contentStr: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
    * 获取字符串Base64Decoder值
    * @param {*} contentStr 
    * @returns 
    */
  getStrBase64Decoder(contentStr: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void



  /**
    * 获取文件md5值
    * @param {*} filePath 
    * @returns 
    */
  getFileMd5(filePath: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void
  /**
   * 获取文件大小
   * @param {*} filePath 
   * @returns 
   */
  getFileSize(filePath: String, sCallback: (sJson) => {}, eCallBack: (eJson) => {}): void

  /**
     * 获取字符串md5值
     * @param {*} contentStr 
     * @returns 
     */
  getStrMd5Promise(contentStr): Promise

  /**
  * 获取字符串Base64Encoder值
  * @param {*} contentStr 
  * @returns 
  */
  getStrBase64EncoderPromise(contentStr: String): void
  /**
    * 获取字符串Base64Decoder值
    * @param {*} contentStr 
    * @returns 
    */
  getStrBase64DecoderPromise(contentStr: String): void

  /**
   * 获取文件md5值
   * @param {*} filePath 
   * @returns 
   */
  getFileMd5Promise(filePath): Promise
  /**
   * 获取文件大小
   * @param {*} filePath 
   * @returns 
   */
  getFileSizePromise(filePath): Promise

  //
  /**
   * 获取网络链接状态
   */
  connectNet(): boolean

  /**
   * 读取指定文件名内的文本内容
   * @param {*} fileName 
   * @param {*} path
   * @result  读取的文本字符串 
   */
  readTextFSdcard(path: String, fileName: String): String
  /**
   * 判断文件或路径是否存在
   * @param {*} path 
   * @result true为存在
   */
  isExists(path: String): Boolean
  /**
   * 创建文件路径
   * @param {*} path 
   * @result true为成功，false为失败
   */
  createPath(path: String): Boolean
  /**
   * 删除文件或者路径，包含子文件无法删除
   * @param {*} path 
   * @result true为成功，fasle为失败
   */
  deletePathOrFile(path: String): Boolean
  /**
   * 返回当前路径下的所有文件名
   * @param {*} path 
   * @result 返回当前文件夹下的所有文件名字符串，文件名以|分割
   */
  listFiles(path: String): String
  /**
   * 判断文件或者文件夹
   * @param {*} path
   * @result true为目录，false为文件
   */
  dirOrFile(path: String): Boolean

  /***
   * 复制文件到指定目录
   * @param {string} srcPath
   * @param {string} destDir
   */
  copyFile(srcPath, destDir): void

  /**
   * 获取设备SN
   */
  getSn(): String

  /**
  * 保存键值对
  * @param {*} key    键
  * @param {*} value  值
  */
  putKeyValue(key: String, value: String): void

  /**
   * 清空所有键值对
   */
  clearAllKeyValue(): Boolean
  /**
   * 通过键值获取保存的字符串
   * @param {*} key      键
   * @param {*} defalut  值不存在时候，返回的默认值
   */
  getValueByKey(key: String, defalut: String): String
  /**
   * 将字符串生成二维码，并以base64字符串返回
   * @param {*} qrvalue  需要生成二维码的字符串
   * @param {*} width    二维码图片的宽度
   * @param {*} height   二维码图片的高度
   * @result             返回经过bas464编码后的二维码图片
   */
  string2QrBase64(qrvalue: String, width: String, height: String): String
  /**
   * 将base64编码后的图片保存到sd卡
   * @param {*} base64Img  图片base64编码后的字符串
   * @param {*} format    保存的图片类型，支持bmp,jpg,png,webp四种
   * @param {*} path       保存路径
   * @param {*} fileName    保存文件名
   * @result                返回true为保存成功，fasle保存失败
   */
  saveBase64Img(base64Img: String, format: String, path: String, fileName: String): Boolean

  /**
   * 设置HTTP请求头
   * @param {Array<HttpHead>} heads
   */
  httpSetHeadsPromise(heads: Array<HttpHead>): Promise
  /**
 * Promise
 * http post
 * @param url url
 * @param requestBody post请求体字符串
 * @param bodyType (json|form) 对应接口请求参数json字符串
 */
  httpPostPromise(url: String, requestBody: String | Array<kvForm>, bodyType: "json" | "form"): Promise

  /**
   * Promise
   * http get
   * @param url url
   */
  httpGetPromise(url: String): Promise
  /**
   * Promise
   * http下载文件到sd卡
   * @param {String} url 下载地址
   * @param {String} path 保存的路径
   * @param {String} file 保存的文件名
   * @param {(sJson)=>{}} sCallback 
   * @param {(eJson)=>{}} eCallBack 
   */
  httpDownFilePromise(url: String, path: String, fileName: String): Promise


  /***
  * 初始化数据库
  * @param {String} dbPath 数据库路径
  * @param {String} dbName 数据库名字
    @param {(sJson)=>{}} sCallback 
  * @param {(eJson)=>{}} eCallBack 
  * 
  */
  initDBPromise(dbPath: String, dbName: String): Promise
  /**
   * 打开数据库
   * @param {String} dbPath 数据库存储路径
   * @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {Boolean}  creata 数据库不存在是否创建
   * 
   */
  openDBPromise(dbKey: String, create: Boolean): Promise
  /**
   *关闭数据库 
   * @param {*} dbKey dbKey initDB获取到的dbKey
   */
  closeDBPromise(dbKey: String): Promise
  /**
   * 获取数据库版本号
   * @param {*} dbKey dbKey initDB获取到的dbKey
   */
  getDBVersionPromise(dbKey: String): Promise
  /**
  * 获取数据库状态，是否正常打开
  * @param {*} dbKey dbKey initDB获取到的dbKey
  */
  getDBStatePromise(dbKey: String): Promise

  /** 
  *  执行sql语句，创建数据表等
   * 
   * <ul>
   *   <li>ALTER TABLE</li>
   *   <li>CREATE or DROP table / trigger / view / index / virtual table</li>
   *   <li>REINDEX</li>
   *   <li>RELEASE</li>
   *   <li>SAVEPOINT</li>
   *   <li>PRAGMA that returns no data</li>
   * </ul>
   *
   * the SQL statement to be executed. Multiple statements separated by semicolons are not supported.
   * 
  *  @param {String} dbKey dbKey initDB获取到的dbKey
  *  @param {String} sqlStr sql语句 
  */
  execSqlPromise(dbKey: String, sqlStr: String): Promise
  /***
   * 查询数据
     @param {String} dbKey dbKey initDB获取到的dbKey
  *  @param {Boolean} distinct true if you want each row to be unique, false otherwise
   * @param {String} table The table name to compile the query against.
   * @param {Array<String>} columns A list of which columns to return. Passing null will return all columns, which is discouraged to prevent reading data from storage that isn't going to be used.
   * @param {String} selection A filter declaring which rows to return, formatted as an SQL WHERE clause (excluding the WHERE itself). Passing null will return all rows for the given table.
   * @param {Array<String>} selectionArgs You may include ?s in selection, which will be replaced by the values from selectionArgs, in order that they appear in the selection. The values will be bound as Strings.
   * @param {String} groupBy A filter declaring how to group rows, formatted as an SQL GROUP BY clause (excluding the GROUP BY itself). Passing null will cause the rows to not be grouped.
   * @param {String} having A filter declare which row groups to include in the cursor, if row grouping is being used, formatted as an SQL HAVING clause (excluding the HAVING itself). 
   * Passing null will cause all row groups to be included, and is required when row grouping is not being used.
   * @param {String} orderBy How to order the rows, formatted as an SQL ORDER BY clause (excluding the ORDER BY itself). Passing null will use the default sort order, which may be unordered.
   * @param {String} limit Limits the number of rows returned by the query, formatted as LIMIT clause. Passing null denotes no LIMIT clause.
   * 
   */
  queryDBPromise(dbKey: String, distinct: Boolean, table: String, columns: Array<String>, selection: String,
    selectionArgs: Array<String>, groupBy: String, having: String,
    orderBy: String, limit: String): Promise
  /***
   * 查询sql数据
   * @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} querySql 查询sql语句
   */
  rawQueryPromise(dbKey: String, querySql: String): Promise

  /***
  * 查询sql数据 返回key value type
  * @param {String} dbKey dbKey initDB获取到的dbKey
  * @param {String} querySql 查询sql语句
  */
  rawQueryWithTypePromise(dbKey: String, querySql: String): Promise
  /***
  * 查询sql数据 返回key  name
  * @param {String} dbKey dbKey initDB获取到的dbKey
  * @param {String} querySql 查询sql语句
  */
  rawQueryOnlyColumnNamePromise(dbKey: String, querySql: String): Promise
  /***
 * 查询sql数据 返回key  name type
 * @param {String} dbKey dbKey initDB获取到的dbKey
 * @param {String} querySql 查询sql语句
 */
  rawQueryOnlyColumnNameTypePromise(dbKey: String, querySql: String): Promise
  /***
   * 插入数据到数据库
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} table table  the table to insert the row into
   * @param {String} nullColumnHack nullColumnHack 
   *                     optional; may be null. SQL doesn't allow inserting a completely empty row without naming at least one column name.
   *                     If your provided values is empty, no column names are known and an empty row can't be inserted. 
   *                     If not set to null, the nullColumnHack parameter provides the name of nullable column name to explicitly insert a NULL into 
   *                     in the case where your values is empty.values – this map contains the initial column values for the row.
   *                     The keys should be the column names and the values the column values
   *  @param {String} contentValues Array<ContentValue>  this map contains the initial column values for the row. 
   *                                         The keys should be the column names and the values the column values JSONArray  
   *                                           example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}] 
   * 
   */

  insertDBPromise(dbKey: String, table: String, nullColumnHack: String, contentValues: Array<ContentValue>): Promise
  /***
   * 删除数据库数据
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} table table the table to delete from
   * @param {String} whereClause the optional WHERE clause to apply when deleting. Passing null will delete all rows.
   *  @param {Array<String>} whereArgs You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
   */

  deleteDBPromise(dbKey: String, table: String, whereClause: String, whereArgs: Array<String>): Promise
  /***
   * 更新数据库数据
   *  @param {String} dbKey dbKey initDB获取到的dbKey
   *  @param {String} table table a map from column names to new column values. null is a valid value that will be translated to NULL.
   *  @param {String} contentValues contentValuesJsonArrayString  a map from column names to new column values. null is a valid value that will be translated to NULL. JSONArray   example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}] 
   *  @param {String} whereClause   the optional WHERE clause to apply when updating. Passing null will update all rows.
   *  @param {Array<String>} whereArgs   You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
   */

  updateDBPromise(dbKey: String, table: String, contentValues: Array<ContentValue>, whereClause: String, whereArgs: Array<String>): Promise

  /**
    * 分享到微信
    * @param {Boolean} isTimeLine 是否分享到朋友圈 
    * @param {String} title  卡片标题
    * @param {String} summary 卡片内容
    * @param {String} targetUrl 跳转url
    * @param {String} imgPath 图片路径，不传为app图标     
    */
  wxSharePromise(isTimeLine: Boolean, title: String, summary: String, targetUrl: String, imgPath: String)

}

export default Device;