
var JsSdk = (function (win) {
    var deviceInstall = null
    var xApiVersion = 11
    function Device(root) {
        this.idCounter = 0
        this.currentApiVersion = xApiVersion
        this.successCallBacks = {}
        this.errorCallBacks = {}
        this.root = root
    }
    //产生一个规则和java的hashcode的字符串
    Device.prototype._hashCode = function (str) {
        var h = 0;
        var len = str.length;
        var t = 2147483648;
        for (var i = 0; i < len; i++) {
            h = 31 * h + str.charCodeAt(i);
            if (h > 2147483647) h %= t; //java int溢出则取模
        }
        return h;
    }
    Device.prototype.callBackResult = function (key, messgae, err) {
        if (this.successCallBacks[key] != undefined) {
            if (messgae) {
                this.successCallBacks[key](messgae)
            }
        }
        if (this.errorCallBacks[key] != undefined) {
            if (err) {
                this.errorCallBacks[key](err)
            }
        }
    }
    Device.prototype._setKeyCallBack = function (funName, sCallBack, eCallBack) {
        var key = funName + "_" + this._hashCode(funName + "_FUNID_" + (++this.idCounter));
        if (sCallBack != undefined) {
            this.successCallBacks[key] = sCallBack
        }
        if (eCallBack != undefined) {
            this.errorCallBacks[key] = eCallBack
        }
        return key
    }
    Device.prototype._checkEnv = function () {
        if (!win.jsDevice) {
            console.error("仅允许运行在国土调查云app内")
            return null
        }
        if (this.currentApiVersion < this.getXApiVersion()) {
            // throw new Error("device.js版本过低,升级device.js后使用")
            console.error("device.js版本过低,升级device.js后使用")
        }
    }
    /**
     * 获取web工作目录
     * @result H5应用工作目录
     */
    Device.prototype.getWorkPath = function () {
        this._checkEnv()
        var key = this._setKeyCallBack("getWorkPath", undefined, undefined)
        this.root.jsDevice.getWorkPath(key);
    }

    /**
     * 获取H5应用环境api版本
     * @result api版本
     */
    Device.prototype.getXApiVersion = function () {
        if (this.root.jsDevice.getXApiVersion) {
            var key = this._setKeyCallBack("getXApiVersion", undefined, undefined)
            return this.root.jsDevice.getXApiVersion(key);
        } else {
            return -1
        }

    }

    /**
     * 打开扫码
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.startQrCode = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("startQrCode", sCallback, eCallBack)
        this.root.jsDevice.startScanQr(key);

    }

    /**
    * 显示控制台按钮Console
    */
    Device.prototype.showDebugConsoleButton = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("showDebugConsoleButton", sCallback, eCallBack)
        return this.root.jsDevice.showDebugConsoleButton(key);

    }
    /**
      * 隐藏控制台按钮Console
    */
    Device.prototype.dismissDebugConsoleButton = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("dismissDebugConsoleButton", sCallback, eCallBack)
        return this.root.jsDevice.dismissDebugConsoleButton(key);
    }
    /**
     * 打开定位
     * @param {*} sCallback
     * @param {*} eCallBack
     */
    Device.prototype.startLocation = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("startLocation", sCallback, eCallBack)
        this.root.jsDevice.startLocation(key)
    }
    /**
    * 关闭定位
    * @param {*} sCallback
    * @param {*} eCallBack
    */
    Device.prototype.stopLocation = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("stopLocation", sCallback, eCallBack)
        this.root.jsDevice.stopLocation(key)
    }
    /**
    * 定位
    * @param {*} sCallback
    * @param {*} eCallBack
    */
    Device.prototype.requestLocation = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("requestLocation", sCallback, eCallBack)
        this.root.jsDevice.requestLocation(key)
    }
    /**
    * 添加定位监听器
    * @param {*} sCallback
    * @param {*} eCallBack
    */
    Device.prototype.addLocationListener = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("addLocationListener", sCallback, eCallBack)
        this.root.jsDevice.addLocationListener(key)
    }
    /**
    * 移除定位监听器
    * @param {*} sCallback
    * @param {*} eCallBack
    */
    Device.prototype.removeLocationListener = function (sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("removeLocationListener", sCallback, eCallBack)
        this.root.jsDevice.removeLocationListener(key)
    }



    /**
     * 分享到微信
     * @param {Boolean} isTimeLine 是否分享到朋友圈
     * @param {String} title  卡片标题
     * @param {String} summary 卡片内容
     * @param {String} targetUrl 跳转url
     * @param {String} imgPath 图片路径，不传为app图标
     * @param {String} sCallback
     * @param {String} eCallBack
     */
    Device.prototype.wxShare = function (
        isTimeLine,
        title,
        summary,
        targetUrl,
        imgPath, sCallback, eCallBack
    ) {
        this._checkEnv()
        var key = this._setKeyCallBack("startQrCode", sCallback, eCallBack)
        this.root.jsDevice.wxShare(key, isTimeLine,
            title,
            summary,
            targetUrl,
            imgPath);
    }

    /**
     * 打开相机
     * @param {string} paramJsonStr 传递到相机的参数
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.goTakePicture = function (paramJsonStr, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("goTakePicture", sCallback, eCallBack)
        this.root.jsDevice.goTakePicture(key, paramJsonStr)
    }
    /**
     * 通过url上传文件到远程服务器
     * @param {string} localPath 本地路径
     * @param {string} header
     * @param {string} writeUrl
     * @param {string} readUrl
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.putFile2CloudByUrl = function (
        localPath, header, writeUrl, readUrl, sCallback, eCallBack
    ) {
        this._checkEnv()
        var key = this._setKeyCallBack("putFile2CloudByUrl", sCallback, eCallBack)
        this.root.jsDevice.putFile2CloudByUrl(key, localPath, header, writeUrl, readUrl,)
    }
    /**
  * 上传文件到远程服务器
  * @param {string} localPath 本地路径
  * @param {string} header
  * @param {string} writeUrl
  * @param {string} readUrl
  * @param {(sJson)=>{}} sCallback
  * @param {(eJson)=>{}} eCallBack
  */
    Device.prototype.putFile2Cloud = function (
        localPath, serverPath, sCallback, eCallBack
    ) {
        this._checkEnv()
        var key = this._setKeyCallBack("putFile2Cloud", sCallback, eCallBack)
        this.root.jsDevice.putFile2Cloud(key, localPath, serverPath)
    }


    /***
    * 初始化数据库
    * @param {*} dbPath 数据库路径
    * @param {*} dbName 数据库名字
      @param {(sJson)=>{}} sCallback
    * @param {(eJson)=>{}} eCallBack
    *
    */
    Device.prototype.initDB = function (dbPath, dbName, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("initDB", sCallback, eCallBack)
        this.root.jsDevice.initDB(key, dbPath, dbName)
    }
    /**
     * 打开数据库
     * @param {*} dbPath 数据库存储路径
     * @param {*} dbKey dbKey initDB获取到的dbKey
     * @param {*}  creata 数据库不存在是否创建
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     *
     */
    Device.prototype.openDB = function (dbKey, create, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("openDB", sCallback, eCallBack)
        this.root.jsDevice.openDB(key, dbKey, create)
    }
    /**
     *关闭数据库
     * @param {*} dbKey dbKey initDB获取到的dbKey
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.closeDB = function (dbKey, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("closeDB", sCallback, eCallBack)
        this.root.jsDevice.closeDB(key, dbKey)

    }
    /**
     * 获取数据库版本号
     * @param {*} dbKey dbKey initDB获取到的dbKey
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.getDBVersion = function (dbKey, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getDBVersion", sCallback, eCallBack)
        this.root.jsDevice.getDBVersion(key, dbKey)
    }
    /**
    * 获取数据库状态，是否正常打开
    * @param {*} dbKey dbKey initDB获取到的dbKey
    *  @param {(sJson)=>{}} sCallback
    * @param {(eJson)=>{}} eCallBack
    */
    Device.prototype.getDBState = function (dbKey, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getDBState", sCallback, eCallBack)
        this.root.jsDevice.getDBState(key, dbKey)
    }

    /**
    *  执行sql语句，创建数据表等
     *
     * <ul>
     *   <li>ALTER TABLE</li>
     *   <li>CREATE or DROP table / trigger / view / index / virtual table</li>
     *   <li>REINDEX</li>
     *   <li>RELEASE</li>
     *   <li>SAVEPOINT</li>
     *   <li>PRAGMA that returns no data</li>
     * </ul>
     *
     * the SQL statement to be executed. Multiple statements separated by semicolons are not supported.
     *
    *  @param {String} dbKey dbKey initDB获取到的dbKey
    *  @param {String} sqlStr sql语句
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
    */
    Device.prototype.execSql = function (dbKey, sqlStr, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("execSql", sCallback, eCallBack)
        this.root.jsDevice.execSql(key, dbKey, sqlStr)
    }
    /***
     * 查询数据
       @param {String} dbKey dbKey initDB获取到的dbKey
    *  @param {Boolean} distinct true if you want each row to be unique, false otherwise
     * @param {String} table The table name to compile the query against.
     * @param {Array<String>} columns A list of which columns to return. Passing null will return all columns, which is discouraged to prevent reading data from storage that isn't going to be used.
     * @param {String} selection A filter declaring which rows to return, formatted as an SQL WHERE clause (excluding the WHERE itself). Passing null will return all rows for the given table.
     * @param {Array<String>} selectionArgs You may include ?s in selection, which will be replaced by the values from selectionArgs, in order that they appear in the selection. The values will be bound as Strings.
     * @param {String} groupBy A filter declaring how to group rows, formatted as an SQL GROUP BY clause (excluding the GROUP BY itself). Passing null will cause the rows to not be grouped.
     * @param {String} having A filter declare which row groups to include in the cursor, if row grouping is being used, formatted as an SQL HAVING clause (excluding the HAVING itself).
     * Passing null will cause all row groups to be included, and is required when row grouping is not being used.
     * @param {String} orderBy How to order the rows, formatted as an SQL ORDER BY clause (excluding the ORDER BY itself). Passing null will use the default sort order, which may be unordered.
     * @param {String} limit Limits the number of rows returned by the query, formatted as LIMIT clause. Passing null denotes no LIMIT clause.
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     *
     */
    Device.prototype.queryDB = function (dbKey, distinct, table, columns, selection,
        selectionArgs, groupBy, having,
        orderBy, limit, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("queryDB", sCallback, eCallBack)
        this.root.jsDevice.queryDB(key, dbKey, distinct, table, columns, selection,
            selectionArgs, groupBy, having,
            orderBy, limit)

    }
    /***
     * 查询sql数据
     * @param {String} dbKey dbKey initDB获取到的dbKey
     * @param {String} querySql 查询sql语句
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.rawQuery = function (dbKey, querySql, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("rawQuery", sCallback, eCallBack)
        this.root.jsDevice.rawQuery(key, dbKey, querySql)
    }
    /***
    * 查询sql数据 返回key value type 字段
    * @param {String} dbKey dbKey initDB获取到的dbKey
    * @param {String} querySql 查询sql语句
    * @param {(sJson)=>{}} sCallback
    * @param {(eJson)=>{}} eCallBack
    */
    Device.prototype.rawQueryWithType = function (dbKey, querySql, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("rawQueryWithType", sCallback, eCallBack)
        this.root.jsDevice.rawQueryWithType(key, dbKey, querySql)
    }

    /***
  * 查询sql数据 返回key name type 字段,无value
  * @param {String} dbKey dbKey initDB获取到的dbKey
  * @param {String} querySql 查询sql语句
  * @param {(sJson)=>{}} sCallback
  * @param {(eJson)=>{}} eCallBack
  */
    Device.prototype.rawQueryOnlyColumnNameType = function (dbKey, querySql, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("rawQueryOnlyColumnNameType", sCallback, eCallBack)
        this.root.jsDevice.rawQueryOnlyColumnNameType(key, dbKey, querySql)
    }
    /***
   * 查询sql数据 返回key  name 字段,无value
   * @param {String} dbKey dbKey initDB获取到的dbKey
   * @param {String} querySql 查询sql语句
   * @param {(sJson)=>{}} sCallback
   * @param {(eJson)=>{}} eCallBack
   */
    Device.prototype.rawQueryOnlyColumnName = function (dbKey, querySql, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("rawQueryOnlyColumnName", sCallback, eCallBack)
        this.root.jsDevice.rawQueryOnlyColumnName(key, dbKey, querySql)
    }
    /***
     * 插入数据到数据库
     *  @param {String} dbKey dbKey initDB获取到的dbKey
     * @param {String} table table  the table to insert the row into
     * @param {String} nullColumnHack nullColumnHack
     *                     optional; may be null. SQL doesn't allow inserting a completely empty row without naming at least one column name.
     *                     If your provided values is empty, no column names are known and an empty row can't be inserted.
     *                     If not set to null, the nullColumnHack parameter provides the name of nullable column name to explicitly insert a NULL into
     *                     in the case where your values is empty.values – this map contains the initial column values for the row.
     *                     The keys should be the column names and the values the column values
     *  @param {*} contentValuesJsonArrayString contentValuesJsonArrayString  this map contains the initial column values for the row.
     *                                         The keys should be the column names and the values the column values JSONArray
     *                                           example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}]
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     *
     */

    Device.prototype.insertDB = function (dbKey, table, nullColumnHack, contentValuesJsonArrayString, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("insertDB", sCallback, eCallBack)
        this.root.jsDevice.insertDB(key, dbKey, table, nullColumnHack, contentValuesJsonArrayString)
    }
    /***
     * 删除数据库数据
     *  @param {String} dbKey dbKey initDB获取到的dbKey
     * @param {String} table table the table to delete from
     * @param {String} whereClause the optional WHERE clause to apply when deleting. Passing null will delete all rows.
     *  @param {Array<String>} whereArgs You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
     *  @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */

    Device.prototype.deleteDB = function (dbKey, table, whereClause, whereArgs, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("deleteDB", sCallback, eCallBack)
        this.root.jsDevice.deleteDB(key, dbKey, table, whereClause, whereArgs)
    }
    /***
     * 更新数据库数据
     *  @param {String} dbKey dbKey initDB获取到的dbKey
     *  @param {String} table table a map from column names to new column values. null is a valid value that will be translated to NULL.
     *  @param {*} contentValuesJsonArrayString contentValuesJsonArrayString  a map from column names to new column values. null is a valid value that will be translated to NULL. JSONArray   example [{key:"key",value:"value",type:"string"},{key:"key2",value:"value2",type:"string"}]
     *  @param {Array<String>} whereClause   the optional WHERE clause to apply when updating. Passing null will update all rows.
     *  @param {Array} whereArgs   You may include ?s in the where clause, which will be replaced by the values from whereArgs. The values will be bound as Strings.
     *  @param {(sJson)=>{}} sCallback
     *  @param {(eJson)=>{}} eCallBack
     */

    Device.prototype.updateDB = function (dbKey, table, contentValuesJsonArrayString, whereClause, whereArgs, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("updateDB", sCallback, eCallBack)
        this.root.jsDevice.updateDB(key, dbKey, table, contentValuesJsonArrayString, whereClause, whereArgs)
    }


    /**
  * http set head
  * @param {String} heads [{key:value}...]
  * * @param {(sJson)=>{}} sCallback
    * @param {(eJson)=>{}} eCallBack
  */
    Device.prototype.httpSetHeads = function (heads, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("httpSetHeads", sCallback, eCallBack)
        this.root.jsDevice.httpSetHeads(key, heads);
    }

    /**
     *http post
     * @param {String} url    url
     * @param {String} requestBody  post请求体字符串
     * @param {String} bodyType   (json|form|text) 对应接口请求参数json字符串
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.send2ServerPost = function (url, requestBody, bodyType, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerPost", sCallback, eCallBack)
        this.root.jsDevice.send2ServerPost(key, url, requestBody, bodyType);
    }
    /**
     *http get
     * @param {String} url    url
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.send2ServerGet = function (url, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerGet", sCallback, eCallBack)
        this.root.jsDevice.send2ServerGet(key, url);
    }
    /**
   *http delete
   * @param {String} url    url
   * @param {(sJson)=>{}} sCallback
   * @param {(eJson)=>{}} eCallBack
   */
    Device.prototype.send2ServerDelete = function (url, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerDeleteNoBody", sCallback, eCallBack)
        this.root.jsDevice.send2ServerDelete(key, url);
    }
    /**
    *http delete
    * @param {String} url    url
    * @param {String} requestBody  post请求体字符串
    * @param {String} bodyType   (json|form|text) 对应接口请求参数json字符串
    * @param {(sJson)=>{}} sCallback
    * @param {(eJson)=>{}} eCallBack
    */
    Device.prototype.send2ServerDelete = function (url, requestBody, bodyType, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerDelete", sCallback, eCallBack)
        this.root.jsDevice.send2ServerDelete(key, url, requestBody, bodyType);
    }
    /**
     *http put
     * @param {String} url    url
     * @param {String} requestBody  post请求体字符串
     * @param {String} bodyType   (json|form|text) 对应接口请求参数json字符串
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.send2ServerPut = function (url, requestBody, bodyType, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerPut", sCallback, eCallBack)
        this.root.jsDevice.send2ServerPut(key, url, requestBody, bodyType);
    }
    /**
     *http patch
     * @param {String} url    url
     * @param {String} requestBody  post请求体字符串
     * @param {String} bodyType   (json|form|text) 对应接口请求参数json字符串
     * @param {(sJson)=>{}} sCallback
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.send2ServerPatch = function (url, requestBody, bodyType, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("send2ServerPatch", sCallback, eCallBack)
        this.root.jsDevice.send2ServerPatch(key, url, requestBody, bodyType);
    }

    /**
     * 保存文件到sd卡
     * @param {String} url 下载地址
     * @param {String} path 保存的路径
     * @param {String} file 保存的文件名
     * @param {Boolean} needProgress 是否需要回调下载进度值
     * @param {(sJson)=>{}} sCallback sJson={state:boolean,progress:float} state为false正在下载，state为true下载完成 progress下载进度 0~1
     * @param {(eJson)=>{}} eCallBack
     */
    Device.prototype.downloadFile = function (url, path, fileName, needProgress, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("downloadFile", sCallback, eCallBack)

        return this.root.jsDevice.downloadFile(key, url, path, fileName, needProgress)
    }

    /**
     * 将文本内容固化到sd卡，可以保存json字符串或图片的base64字符串
     * @param {String} path       文件路径
     * @param {String} fileName   保存的文件名
     * @param {String} strString  字符串内容
     * @result true为成功，false为失败
     */
    Device.prototype.writeText2Sdcard = function (path, fileName, strString) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("writeText2Sdcard", sCallback, eCallBack)
        this.root.jsDevice.writeText2Sdcard(key, path, fileName, strString)
    }
    /**
     * 读取指定文件名内的文本内容
     * @param {*} fileName
     * @param {*} path
     * @result  读取的文本字符串
     */
    Device.prototype.readTextFSdcard = function (path, fileName) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("readTextFSdcard", sCallback, eCallBack)
        return this.root.jsDevice.readTextFSdcard(key, path, fileName)
    }
    /**
     * 判断文件或路径是否存在
     * @param {*} path
     * @result true为存在
     */
    Device.prototype.isExists = function (path) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("isExists", sCallback, eCallBack)
        return this.root.jsDevice.isExists(key, path)
    }
    /**
     * 创建文件路径
     * @param {*} path
     * @result true为成功，false为失败
     */
    Device.prototype.createPath = function (path) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("createPath", sCallback, eCallBack)
        return this.root.jsDevice.createPath(key, path)
    }

    /**
     * 复制文件
     * @param {String} srcPath
     * @param {String} destDir
     * @returns
     */
    Device.prototype.copyFile = function (srcPath, destDir, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("copyFile", sCallback, eCallBack)
        return this.root.jsDevice.copyFile(key, srcPath, destDir)
    }

    /**
     * 删除文件或者路径，包含子文件无法删除
     * @param {*} path
     * @result true为成功，fasle为失败
     */
    Device.prototype.deletePathOrFile = function (path) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("deletePathOrFile", sCallback, eCallBack)
        return this.root.jsDevice.deletePathOrFile(key, path)
    }
    /**
     * 返回当前路径下的所有文件名
     * @param {*} path
     * @result 返回当前文件夹下的所有文件名字符串，文件名以|分割
     */
    Device.prototype.listFiles = function (path) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("listFiles", sCallback, eCallBack)
        return this.root.jsDevice.listFiles(key, path)
    }
    /**
     * 判断文件或者文件夹
     * @param {*} path
     * @result true为目录，false为文件
     */
    Device.prototype.dirOrFile = function (path) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("dirOrFile", sCallback, eCallBack)
        return this.root.jsDevice.dirOrFile(key, path)
    }
    /**
     * 获取设备SN
     */
    Device.prototype.getSn = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("getSn", sCallback, eCallBack)
        return this.root.jsDevice.getSn(key);

    }

    /**
 * 获取应用包名
 */
    Device.prototype.getAppPackageName = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        if (this.root.jsDevice.getAppPackageName) {
            var key = this._setKeyCallBack("getAppPackageName", sCallback, eCallBack)
            return this.root.jsDevice.getAppPackageName(key);
        } else {
            return ""
        }
    }
    /**
   * 获取appVersionCode
   */
    Device.prototype.getAppVersionCode = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        if (this.root.jsDevice.getAppVersionCode) {
            var key = this._setKeyCallBack("getAppVersionCode", sCallback, eCallBack)
            return this.root.jsDevice.getAppVersionCode(key);
        } else {
            return -1
        }
    }
    /**
   * 获取appVersionCode
   */
    Device.prototype.getAppVersionName = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        if (this.root.jsDevice.getAppVersionName) {
            var key = this._setKeyCallBack("getAppVersionName", sCallback, eCallBack)
            return this.root.jsDevice.getAppVersionName(key);
        } else {
            return "0.00"
        }

    }
    /**
     * 获取字符串md5值
     * @param {*} contentStr
     * @returns
     */
    Device.prototype.getStrMd5 = function (contentStr, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getStrMd5", sCallback, eCallBack)
        return this.root.jsDevice.getStrMd5(key, contentStr);
    }
    /**
     * 获取字符串Base64Encoder值
     * @param {*} contentStr
     * @returns
     */
    Device.prototype.getStrBase64Encoder = function (contentStr, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getStrBase64Encoder", sCallback, eCallBack)
        return this.root.jsDevice.getStrBase64Encoder(key, contentStr);
    }
    /**
  * 获取字符串Base64Decoder值
  * @param {*} contentStr
  * @returns
  */
    Device.prototype.getStrBase64Decoder = function (contentStr, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getStrBase64Decoder", sCallback, eCallBack)
        return this.root.jsDevice.getStrBase64Decoder(key, contentStr);
    }
    /**
     * 获取文件md5值
     * @param {*} filePath
     * @returns
     */
    Device.prototype.getFileMd5 = function (filePath, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getFileMd5", sCallback, eCallBack)
        return this.root.jsDevice.getFileMd5(key, filePath);
    }
    /**
     * 获取文件大小
     * @param {*} filePath
     * @returns
     */
    Device.prototype.getFileSize = function (filePath, sCallback, eCallBack) {
        this._checkEnv()
        var key = this._setKeyCallBack("getFileSize", sCallback, eCallBack)
        return this.root.jsDevice.getFileSize(key, filePath);
    }
    /**
     * 获取设备是否有网络链接
     */
    Device.prototype.connectNet = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("connectNet", sCallback, eCallBack)
        return this.root.jsDevice.connectNet(key);
    }
    /**
    * 保存键值对
    * @param {*} key    键
    * @param {*} value  值
    */
    Device.prototype.putKeyValue = function (key, value) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var funKey = this._setKeyCallBack("putKeyValue", sCallback, eCallBack)
        this.root.jsDevice.putKeyValue(funKey, key, value);

    }

    /**
   * 清空所有键值对
   */
    Device.prototype.clearAllKeyValue = function () {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var funKey = this._setKeyCallBack("clearAllKeyValue", sCallback, eCallBack)
        this.root.jsDevice.clearAllKeyValue(funKey);

    }
    /**
     * 通过键值获取保存的字符串
     * @param {*} key      键
     * @param {*} defalut  值不存在时候，返回的默认值
     */
    Device.prototype.getValueByKey = function (key, defalut) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var funKey = this._setKeyCallBack("getValueByKey", sCallback, eCallBack)
        return this.root.jsDevice.getValueByKey(funKey, key, defalut);

    }
    /**
     * 将字符串生成二维码，并以base64字符串返回
     * @param {*} qrvalue  需要生成二维码的字符串
     * @param {*} width    二维码图片的宽度
     * @param {*} height   二维码图片的高度
     * @result             返回经过bas464编码后的二维码图片
     */
    Device.prototype.string2QrBase64 = function (qrvalue, width, height) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("string2QrBase64", sCallback, eCallBack)
        return this.root.jsDevice.string2QrBase64(key, qrvalue, width, height)
    }
    /**
     * 将base64编码后的图片保存到sd卡
     * @param {*} base64Img  图片base64编码后的字符串
     * @param {*} format    保存的图片类型，支持bmp,jpg,png,webp四种
     * @param {*} path       保存路径
     * @param {*} fileName    保存文件名
     * @result                返回true为保存成功，fasle保存失败
     */
    Device.prototype.saveBase64Img = function (base64Img, format, path, fileName) {
        this._checkEnv()
        var sCallback = undefined
        var eCallBack = undefined
        var key = this._setKeyCallBack("saveBase64Img", sCallback, eCallBack)
        return this.root.jsDevice.saveBase64Img(key, base64Img, format, path, fileName)
    }

    return {
        getInstance: function () {

            if (!deviceInstall) {
                deviceInstall = new Device(win);
            }
            return deviceInstall;
        }
    }



})(window)
var device = JsSdk.getInstance()

device.httpSetHeadsPromise = function (heads) {
    var strHeadsJson = JSON.stringify(heads)
    return new Promise((resolve, reason) => {
        device.httpSetHeads(strHeadsJson, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}
device.httpGetPromise = function (url) {
    return new Promise((resolve, reason) => {
        device.send2ServerGet(url, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }
        })
    })
}
device.httpPostPromise = function (url, requestBody, bodyType) {
    if (typeof requestBody !== "string") {
        requestBody = JSON.stringify(requestBody)
    }
    return new Promise((resolve, reason) => {
        device.send2ServerPost(url, requestBody, bodyType, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }

        })
    })
}
device.httpDeletePromise = function (url) {
    return new Promise((resolve, reason) => {
        device.send2ServerDelete(url, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }
        })
    })
}
device.httpDeletePromise = function (url, requestBody, bodyType) {
    if (typeof requestBody !== "string") {
        requestBody = JSON.stringify(requestBody)
    }
    return new Promise((resolve, reason) => {
        device.send2ServerDelete(url, requestBody, bodyType, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }

        })
    })
}
device.httpPutPromise = function (url, requestBody, bodyType) {
    if (typeof requestBody !== "string") {
        requestBody = JSON.stringify(requestBody)
    }
    return new Promise((resolve, reason) => {
        device.send2ServerPut(url, requestBody, bodyType, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }

        })
    })
}
device.httpPatchPromise = function (url, requestBody, bodyType) {
    if (typeof requestBody !== "string") {
        requestBody = JSON.stringify(requestBody)
    }
    return new Promise((resolve, reason) => {
        device.send2ServerPatch(url, requestBody, bodyType, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            if (eJson.indexOf("Unable to resolve host") > -1) {
                resolve({ error: eJson })
            } else {
                reason(eJson)
            }

        })
    })
}
device.httpDownFilePromise = function (url, path, fileName) {
    return new Promise((resolve, reason) => {
        device.downloadFile(url, path, fileName, false, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.getStrMd5Promise = function (contentStr) {
    return new Promise((resolve, reason) => {
        device.getStrMd5(contentStr, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.getStrBase64DecoderPromise = function (contentStr) {
    return new Promise((resolve, reason) => {
        device.getStrBase64Decoder(contentStr, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.getStrBase64EncoderPromise = function (contentStr) {
    return new Promise((resolve, reason) => {
        device.getStrBase64Encoder(contentStr, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.getFileMd5Promise = function (filePath) {
    return new Promise((resolve, reason) => {
        device.getFileMd5(filePath, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.getFileSizePromise = function (filePath) {
    return new Promise((resolve, reason) => {
        device.getFileSize(filePath, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.initDBPromise = function (dbPath, dbName) {
    return new Promise((resolve, reason) => {
        device.initDB(dbPath, dbName, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.openDBPromise = function (dbKey, create) {
    return new Promise((resolve, reason) => {
        device.openDB(dbKey, create, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.closeDBPromise = function (dbKey) {
    return new Promise((resolve, reason) => {
        device.closeDB(dbKey, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}

device.getDBVersionPromise = function (dbKey) {
    return new Promise((resolve, reason) => {
        device.getDBVersion(dbKey, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.getDBStatePromise = function (dbKey) {
    return new Promise((resolve, reason) => {
        device.getDBState(dbKey, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.execSqlPromise = function (dbKey, sqlStr) {
    return new Promise((resolve, reason) => {
        device.execSql(dbKey, sqlStr, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.queryDBPromise = function (dbKey, distinct, table, columns, selection,
    selectionArgs, groupBy, having,
    orderBy, limit) {
    return new Promise((resolve, reason) => {
        device.queryDB(dbKey, distinct, table, columns, selection,
            selectionArgs, groupBy, having,
            orderBy, limit, (sJson) => {
                resolve(sJson)
            }, (eJson) => {
                // reason(eJson)
                resolve({ error: eJson })
            })
    })
}

device.rawQueryPromise = function (dbKey, querySql) {
    return new Promise((resolve, reason) => {
        device.rawQuery(dbKey, querySql, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.rawQueryWithTypePromise = function (dbKey, querySql) {
    return new Promise((resolve, reason) => {
        device.rawQueryWithType(dbKey, querySql, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.rawQueryOnlyColumnNamePromise = function (dbKey, querySql) {
    return new Promise((resolve, reason) => {
        device.rawQueryOnlyColumnName(dbKey, querySql, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)

            resolve({ error: eJson })
        })
    })
}

device.rawQueryOnlyColumnNameTypePromise = function (dbKey, querySql) {
    return new Promise((resolve, reason) => {
        device.rawQueryOnlyColumnNameType(dbKey, querySql, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)

            resolve({ error: eJson })
        })
    })
}


device.insertDBPromise = function (dbKey, table, nullColumnHack, contentValues) {
    var contentValuesJsonArrayString = JSON.stringify(contentValues)
    return new Promise((resolve, reason) => {
        device.insertDB(dbKey, table, nullColumnHack, contentValuesJsonArrayString, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}


device.deleteDBPromise = function (dbKey, table, whereClause, whereArgs) {
    return new Promise((resolve, reason) => {
        device.deleteDB(dbKey, table, whereClause, whereArgs, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.updateDBPromise = function (dbKey, table, contentValues, whereClause, whereArgs) {
    var contentValuesJsonArrayString = JSON.stringify(contentValues)
    return new Promise((resolve, reason) => {
        device.updateDB(dbKey, table, contentValuesJsonArrayString, whereClause, whereArgs, (sJson) => {
            resolve(sJson)
        }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.copyFilePromise = function (srcPath, destDir) {
    return new Promise((resolve, reason) => {
        device.copyFile(srcPath, destDir, (sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}
device.goTakePicturePromise = function (paramJsonStr) {
    return new Promise((resolve, reason) => {
        device.goTakePicture(paramJsonStr, (sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}
device.putFile2CloudByUrlPromise = function (localPath, header, writeUrl, readUrl) {
    return new Promise((resolve, reason) => {
        device.putFile2CloudByUrl(localPath, header, writeUrl, readUrl, (sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}

device.putFile2CloudPromise = function (localPath, serverPath) {
    return new Promise((resolve, reason) => {
        device.putFile2Cloud(localPath, serverPath, (sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })

}
device.startLocationPromise = function () {
    return new Promise((resolve, reason) => {
        device.startLocation((sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.stopLocationPromise = function () {
    return new Promise((resolve, reason) => {
        device.stopLocation((sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.requestLocationPromise = function () {
    return new Promise((resolve, reason) => {
        device.requestLocation((sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.addLocationListenerPromise = function () {
    return new Promise((resolve, reason) => {
        device.addLocationListener((sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}
device.removeLocationListenerPromise = function () {
    return new Promise((resolve, reason) => {
        device.removeLocationListener((sJson) => { resolve(sJson) }, (eJson) => {
            // reason(eJson)
            resolve({ error: eJson })
        })
    })
}

device.wxSharePromise = function (
    isTimeLine,
    title,
    summary,
    targetUrl,
    imgPath
) {

    return new Promise((resolve, reason) => {
        device.wxShare(
            isTimeLine,
            title,
            summary,
            targetUrl,
            imgPath, (sJson) => {
                resolve(sJson)
            }, (eJson) => {
                reason(eJson)
            }
        )
    })
}


window.device = device
export default device